@@ -1,28 +1,31 @@
 import pytest
 
-from sql_tstring import Absent, sql, sql_context
+from sql_tstring import RewritingValue, sql, sql_context
 
 
 def test_order_by() -> None:
-    a = Absent()
+    a = RewritingValue.ABSENT
     b = "x"
     with sql_context(columns={"x"}):
-        assert ("select x from y order by x", []) == sql(
+        assert ("SELECT x FROM y ORDER BY x", []) == sql(
             "SELECT x FROM y ORDER BY {a}, {b}", locals()
         )
 
 
-def test_order_by_direction() -> None:
-    a = "ASC"
+@pytest.mark.parametrize(
+    "a",
+    ["ASC", "ASCENDING", "asc", "ascending"],
+)
+def test_order_by_direction(a: str) -> None:
     b = "x"
     with sql_context(columns={"x"}):
-        assert ("select x from y order by x ASC", []) == sql(
+        assert (f"SELECT x FROM y ORDER BY x {a}", []) == sql(
             "SELECT x FROM y ORDER BY {b} {a}", locals()
         )
 
 
 def test_order_by_invalid_column() -> None:
-    a = Absent()
+    a = RewritingValue.ABSENT
     b = "x"
     with pytest.raises(ValueError):
         sql("SELECT x FROM y ORDER BY {a}, {b}", locals())
@@ -31,9 +34,9 @@ def test_order_by_invalid_column() -> None:
 @pytest.mark.parametrize(
     "lock_type, expected",
     (
-        ("", "select x from y for update"),
-        ("NOWAIT", "select x from y for update NOWAIT"),
-        ("SKIP LOCKED", "select x from y for update SKIP LOCKED"),
+        ("", "SELECT x FROM y FOR UPDATE"),
+        ("NOWAIT", "SELECT x FROM y FOR UPDATE NOWAIT"),
+        ("SKIP LOCKED", "SELECT x FROM y FOR UPDATE SKIP LOCKED"),
     ),
 )
 def test_lock(lock_type: str, expected: str) -> None:
@@ -41,5 +44,5 @@ def test_lock(lock_type: str, expected: str) -> None:
 
 
 def test_absent_lock() -> None:
-    a = Absent
-    assert ("select x from y", []) == sql("SELECT x FROM y FOR UPDATE {a}", locals())
+    a = RewritingValue.ABSENT
+    assert ("SELECT x FROM y", []) == sql("SELECT x FROM y FOR UPDATE {a}", locals())
